==> haskell-polyparse-1.13.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 polyparse
version:              1.13.1
visibility:           public
id:                   polyparse-1.13.1-Kzbu3d62mnu6HLgy0ka478
key:                  polyparse-1.13.1-Kzbu3d62mnu6HLgy0ka478
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           Andreas Abel
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
synopsis:             A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

    Old homepage: <https://archives.haskell.org/projects.haskell.org/polyparse/>

category:             Text, Parsing
abi:                  ce8b7733c8d7fb00cfc9c730236dc329
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-9.4.8/site-local/polyparse-1.13.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/polyparse-1.13.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/polyparse-1.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polyparse
hs-libraries:         HSpolyparse-1.13.1-Kzbu3d62mnu6HLgy0ka478
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.13.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 polyparse
version:              1.13.1
visibility:           public
id:                   polyparse-1.13.1-GNSrxCypyqMZdcZAjLboq
key:                  polyparse-1.13.1-GNSrxCypyqMZdcZAjLboq
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           Andreas Abel
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
synopsis:             A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

    Old homepage: <https://archives.haskell.org/projects.haskell.org/polyparse/>

category:             Text, Parsing
abi:                  7d7f573734f1a2f7a4313d7b852877b0
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-9.6.6/site-local/polyparse-1.13.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/polyparse-1.13.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/polyparse-1.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polyparse
hs-libraries:         HSpolyparse-1.13.1-GNSrxCypyqMZdcZAjLboq
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
